/*
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Copyright (c) 2011 digitalSTROM.org, Zurich, Switzerland
 *  Author: Sebastian Scholz <digitalstrom@sunshine-studios.org>
 */


Ext.define('DSS.addon.Metering.stores.CircuitModel', {
	extend : 'Ext.data.Model',
	fields : ['name', 'dsid', 'text'],
	proxy : {
		type : 'ajax',
		actionMethods : {
			read : 'GET'
		},
		url : '/json/apartment/getCircuits',
		pageParam : undefined,
		limitParam : undefined,
		startParam : undefined,
		reader : {
			type : 'json',
			root : 'result.circuits',
			successProperty : 'ok'
		}
	},

	constructor : function(data) {
		data.text = data.name || data.dsid.toString().slice(16);
		
		this.callParent(arguments);
	}
});

Ext.define('DSS.addon.Metering.stores.CircuitViewStore', {
	extend : 'Ext.data.Store',
	model : 'DSS.addon.Metering.stores.CircuitModel',

	/*
	 * load function must be overridden so that new records are appended
	 * instead of dropping existing records
	 */

	load : function(options) {
		var me = this;
		options = options || {};

		if(Ext.isFunction(options)) {
			options = {
				callback : options
			};
		}

		Ext.applyIf(options, {
			groupers : me.groupers.items,
			page : me.currentPage,
			start : (me.currentPage - 1) * me.pageSize,
			limit : me.pageSize,
			addRecords : true
		});

		return me.callParent([options]);
	}
});

Ext.define('DSS.addon.Metering.stores.ResolutionModel', {
	extend : 'Ext.data.Model',
	fields : ['resolution', 'name'],
	proxy : {
		type : 'ajax',
		actionMethods : {
			read : 'GET'
		},
		url : '/json/metering/getResolutions',
		pageParam : undefined,
		limitParam : undefined,
		startParam : undefined,
		reader : {
			type : 'json',
			root : 'result.resolutions',
			successProperty : 'ok'
		}
	},
	setName : function(name) {
		this.set('name', name);
	}
});

Ext.define('DSS.addon.Metering.stores.ResolutionStore', {
	extend : 'Ext.data.Store',
	model : 'DSS.addon.Metering.stores.ResolutionModel',
	autoload : true
});

Ext.define('DSS.addon.Metering.stores.SceneNameModel', {
	extend : 'Ext.data.Model',
	fields : [{
		name : 'id',
		type : 'integer',
		persist : false,
		defaultValue : 0
	}],

	hasMany : {
		name : 'zones',
		model : 'DSS.addon.Metering.stores.ZoneNameModel'
	},

	proxy : {
		type : 'ajax',
		actionMethods : {
			read : 'GET'
		},
		url : '/json/property/query?query=/apartment/zones/*(ZoneID,name,scenes)/groups/*(group)/scenes/*(scene,name)',
		pageParam : undefined,
		limitParam : undefined,
		startParam : undefined,
		reader : {
			type : 'json',
			root : 'result',
			successProperty : 'ok'
		}
	}
});

Ext.define('DSS.addon.Metering.stores.SceneNameStore', {
	extend : 'Ext.data.Store',
	model : 'DSS.addon.Metering.stores.SceneNameModel',
	autoload : true
});

Ext.define('DSS.addon.Metering.stores.ZoneNameModel', {
	extend : 'Ext.data.Model',
	fields : ['ZoneID', 'name', 'text'],
	idProperty : 'ZoneID',
	hasMany : {
		name : 'groups',
		model : 'DSS.addon.Metering.stores.GroupNameModel'
	},

	constructor : function(data, iid) {
		data.text = data.name || data.ZoneID;

		this.callParent(arguments);
	}
});

Ext.define('DSS.addon.Metering.stores.GroupNameModel', {
	extend : 'Ext.data.Model',
	fields : ['group'],
	idProperty : 'group',
	hasMany : {
		name : 'scenes',
		model : 'DSS.addon.Metering.stores.MySceneModel'
	}
});

Ext.define('DSS.addon.Metering.stores.MySceneModel', {
	extend : 'Ext.data.Model',
	fields : ['scene', 'name'],
	belongsTo: {name: 'group', model: 'DSS.addon.Metering.stores.GroupNameModel'},
	idProperty : 'scene'
});
